@@ -1,10 +1,10 @@
 package Net::DNS::RR::DNSKEY;
 
 #
-# $Id: DNSKEY.pm 1179 2014-03-19 21:46:58Z willem $
+# $Id: DNSKEY.pm 1307 2015-02-02 09:30:57Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1179 $)[1];
+$VERSION = (qw$LastChangedRevision: 1307 $)[1];
 
 
 use strict;
@@ -51,15 +51,14 @@ use MIME::Base64;
 
 	my %algbyval = reverse @algbyname;
 
-	my @algbynum = map { ( $_, 0 + $_ ) } keys %algbyval;	# accept algorithm number
-
-	my %algbyname = map { s /[^A-Za-z0-9]//g; $_ } @algbyname, @algbynum;
+	my @algbynum = map { ( $_, 0 + $_ ) } ( 1 .. 250, keys %algbyval );
 
+	my %algbyname = map { s/[^A-Za-z0-9]//g; $_ } @algbyname, @algbynum;
 
 	sub algbyname {
 		my $name = shift;
 		my $key	 = uc $name;				# synthetic key
-		$key =~ s /[^A-Z0-9]//g;			# strip non-alphanumerics
+		$key =~ s/[^A-Z0-9]//g;				# strip non-alphanumerics
 		return $algbyname{$key} || croak "unknown algorithm $name";
 	}
 
@@ -82,17 +81,16 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 sub encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless $self->{algorithm};
-	pack 'n C2 a*', $self->flags, $self->protocol, $self->algorithm, $self->keybin;
+	my $keybin = $self->keybin || return '';
+	pack 'n C2 a*', $self->flags, $self->protocol, $self->algorithm, $keybin;
 }
 
 
 sub format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	my $keybin = $self->keybin || return '';
+	my $base64 = MIME::Base64::encode $self->keybin || return '';
 	my @params = map $self->$_, qw(flags protocol algorithm);
-	my $base64 = MIME::Base64::encode $keybin;
 	chomp $base64;
 	return join ' ', @params, "(\n$base64 ) ; Key ID =", $self->keytag;
 }
@@ -102,7 +100,7 @@ sub parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->$_(shift) for qw(flags protocol algorithm);
-	$self->publickey(@_);
+	$self->key(@_);
 }
 
 
@@ -166,10 +164,15 @@ sub keybin {
 
 sub privatekeyname {
 	my $self = shift;
-	my $name = lc $self->{owner}->fqdn;
+	my $name = $self->signame;
 	sprintf 'K%s+%03d+%05d.private', $name, $self->algorithm, $self->keytag;
 }
 
+sub signame {
+	my $self = shift;
+	my $name = lc $self->{owner}->fqdn;
+}
+
 
 sub keylength {
 	my $self = shift;
@@ -260,11 +263,8 @@ sub sep {
 }
 
 
-my $warned;
-
 sub is_sep {				## historical
 	my $self = shift;
-	carp "Deprecated method: please use rr->sep(@_)" unless $warned++;
 	return $self->sep(@_) ? 1 : 0;
 }
 
@@ -329,11 +329,12 @@ The format depends on the algorithm of the key being stored.
 
 =head2 privatekeyname
 
-    $privatekeyname=$rr->privatekeyname
+    $privatekeyname = $rr->privatekeyname
 
 Returns the name of the privatekey as it would be generated by
-the BIND dnssec-keygen program. The format of that name being
-K\<fqdn\>+\<algorithm\>+\<keyid\>.private
+the BIND dnssec-keygen program. The format of that name being:
+
+	K<fqdn>+<algorithm>+<keyid>.private
 
 =head2 keylength
 
@@ -343,7 +344,7 @@ Returns the length (in bits) of the modulus calculated from the key text.
 
     print "keytag = ", $rr->keytag, "\n";
 
-Returns the key tag of the key. (RFC2535 4.1.6)
+Returns the 16-bit numerical key tag of the key. (RFC2535 4.1.6)
 
 =head2 zone
 
